// components/Terminal.js
import { useState, useEffect, useRef } from 'react';
import io from 'socket.io-client';
import axios from 'axios';
import { Box, Button, Typography } from '@mui/material';

const Terminal = () => {
  const [output, setOutput] = useState([]);
  const [socket, setSocket] = useState(null);
  const terminalEndRef = useRef(null);
  const terminalRef = useRef(null);
  const [autoScroll, setAutoScroll] = useState(true);

  useEffect(() => {
    axios.get('/api/socket').finally(() => {
      const socket = io();
      setSocket(socket);

      socket.on('python-output', (data) => {
        setOutput((prevOutput) => [...prevOutput, data]);
      });

      return () => {
        socket.disconnect();
      };
    });
  }, []);

  useEffect(() => {
    if (autoScroll) {
      terminalEndRef.current?.scrollIntoView({ behavior: 'smooth' });
    }
  }, [output, autoScroll]);

  const startPythonScript = () => {
    if (socket) {
      axios.get('/api/process?action=start');
    }
  };

  const stopPythonScript = () => {
    if (socket) {
      axios.get('/api/process?action=stop');
    }
  };

  useEffect(() => {
    const handleKeyDown = (event) => {
      if (event.ctrlKey && event.key === 'c') {
        stopPythonScript();
      }
    };

    const handleScroll = () => {
      if (terminalRef.current) {
        const { scrollTop, scrollHeight, clientHeight } = terminalRef.current;
        if (scrollTop < scrollHeight - (clientHeight * 2)) {
            setAutoScroll(false);
        }
        else {
            setAutoScroll(true);
        }
      }
    };

    window.addEventListener('keydown', handleKeyDown);
    if (terminalRef.current) {
      terminalRef.current.addEventListener('scroll', handleScroll);
    }
    return () => {
      window.removeEventListener('keydown', handleKeyDown);
      if (terminalRef.current) {
        terminalRef.current.removeEventListener('scroll', handleScroll);
      }
    };
  }, [socket]);

  return (
    <Box sx={{ display: 'flex', flexDirection: 'column', backgroundColor: 'black', color: 'white', border: 1, borderColor: '#333', borderRadius: 1, width: '100%', height: 400 }}>
      <Box sx={{ padding: 1, backgroundColor: '#333', borderBottom: 1, borderColor: '#444', display: 'flex', justifyContent: 'space-between', alignItems: 'center' }}>
        <Button variant="contained" onClick={startPythonScript}>Start Python Script</Button>
        <Button variant="contained" onClick={stopPythonScript}>Stop Python Script</Button>
      </Box>
      <Box ref={terminalRef} sx={{ flexGrow: 1, padding: 1, overflowY: 'auto', fontFamily: 'monospace' }}>
        {output.map((line, index) => (
          <Typography key={index} sx={{ margin: 0, whiteSpace: 'pre-wrap' }}>{line}</Typography>
        ))}
        <div ref={terminalEndRef} />
      </Box>
    </Box>
  );
};

export default Terminal;
