import Terminal from '../../components/Terminal';
import { useState, useEffect } from 'react';
import { Container, Typography, TextField, Button, Grid, FormControl, InputLabel, Select, MenuItem, RadioGroup, FormControlLabel, Radio, CircularProgress } from '@mui/material';
import axios from 'axios';

export default function Controller() {
  const [config, setConfig] = useState({
    timing_point: '',
    decoder_id: '',
    event_id: '',
    event_name: '',
    timedelta: '',
    // host: '',
    // user: '',
    // password: '',
    // database: '',
    connection_type: 'com_port',
    connection_value: '',
  });
  const [events, setEvents] = useState([]);
  const [loading, setLoading] = useState(false);

  useEffect(() => {
    axios.get('/api/config').then((response) => {
      setConfig(response.data);
    });
    axios.get('/api/events')
      .then(response => setEvents(response.data))
      .catch(error => console.error('Error loading events:', error));
  }, []);

  const handleChange = (e) => {
    const { name, value } = e.target;
    setConfig((prevConfig) => ({ ...prevConfig, [name]: value }));
  };

  const handleSave = async () => {
    setLoading(true);
    await axios.post('/api/config', config).then(() => {
    });
    setLoading(false);
  };

  const handleEventChange = (e) => {
    const selectedEvent = events.find(event => event.eventId === e.target.value);
    setConfig((prevConfig) => ({
      ...prevConfig,
      event_id: selectedEvent?.eventId || '',
      event_name: selectedEvent?.name || ''
    }));
  };

  const handleImport = (e) => {
    const file = e.target.files[0];
    if (file) {
      const reader = new FileReader();
      reader.onload = (e) => {
        const importedConfig = JSON.parse(e.target.result);
        setConfig(importedConfig);
      };
      reader.readAsText(file);
    }
  };

  const handleExport = () => {
    const dataStr = "data:text/json;charset=utf-8," + encodeURIComponent(JSON.stringify(config, null, 2));
    const downloadAnchorNode = document.createElement('a');
    downloadAnchorNode.setAttribute("href", dataStr);
    downloadAnchorNode.setAttribute("download", "config.json");
    document.body.appendChild(downloadAnchorNode);
    downloadAnchorNode.click();
    downloadAnchorNode.remove();
  };

  return (
    <Container>
      <Typography variant="h4" component="h4" gutterBottom>
        Controller
      </Typography>
      <Terminal />
      <Grid container spacing={2} sx={{ marginTop: 2 }}>
        <Grid item xs={12}>
          <TextField
            label="Timing Point"
            name="timing_point"
            value={config.timing_point}
            onChange={handleChange}
            fullWidth
          />
        </Grid>
        <Grid item xs={12}>
          <TextField
            label="Decoder ID"
            name="decoder_id"
            value={config.decoder_id}
            onChange={handleChange}
            fullWidth
          />
        </Grid>
        <Grid item xs={12}>
          <FormControl fullWidth>
            <InputLabel>Event</InputLabel>
            <Select
              value={config.event_id}
              onChange={handleEventChange}
            >
              {events.map((event) => (
                <MenuItem key={event.eventId} value={event.eventId}>
                  {event.name}
                </MenuItem>
              ))}
            </Select>
          </FormControl>
        </Grid>
        <Grid item xs={12}>
          <TextField
            label="Timedelta"
            name="timedelta"
            value={config.timedelta}
            onChange={handleChange}
            fullWidth
          />
        </Grid>
        {/* <Grid item xs={12}>
          <TextField
            label="DB Host"
            name="host"
            value={config.host}
            onChange={handleChange}
            fullWidth
          />
        </Grid>
        <Grid item xs={12}>
          <TextField
            label="DB User"
            name="user"
            value={config.user}
            onChange={handleChange}
            fullWidth
          />
        </Grid>
        <Grid item xs={12}>
          <TextField
            label="DB Password"
            name="password"
            value={config.password}
            onChange={handleChange}
            fullWidth
            type="password"
          />
        </Grid>
        <Grid item xs={12}>
          <TextField
            label="DB Name"
            name="database"
            value={config.database}
            onChange={handleChange}
            fullWidth
          />
        </Grid> */}
        <Grid item xs={12}>
          <FormControl component="fieldset">
            <RadioGroup
              name="connection_type"
              value={config.connection_type}
              onChange={handleChange}
            >
              <FormControlLabel
                value="com_port"
                control={<Radio />}
                label="Com Port"
              />
              <FormControlLabel
                value="network"
                control={<Radio />}
                label="Network"
              />
            </RadioGroup>
          </FormControl>
        </Grid>
        <Grid item xs={12}>
          <TextField
            label="Connection Value"
            name="connection_value"
            value={config.connection_value}
            onChange={handleChange}
            fullWidth
          />
        </Grid>
        <Grid item xs={12}>
          <Button
            variant="contained"
            color="primary"
            onClick={handleSave}
            disabled={loading}
          >
            {loading ? <CircularProgress size={24} /> : 'Speichern'}
          </Button>
          <Button
            variant="contained"
            component="label"
            sx={{ marginLeft: 2 }}
          >
            Importieren
            <input
              type="file"
              hidden
              accept=".json"
              onChange={handleImport}
            />
          </Button>
          <Button variant="contained" onClick={handleExport} sx={{ marginLeft: 2 }}>
            Exportieren
          </Button>
        </Grid>
      </Grid>
    </Container>
  );
}
