import EventForm from '../../../../components/EventForm';
import { useRouter } from 'next/router';
import axios from 'axios';
import { useEffect, useState } from 'react';
import { CircularProgress, Container, Typography } from '@mui/material';

const EventInformation = () => {
  const router = useRouter();
  const { id } = router.query;
  const [eventData, setEventData] = useState({
    name: '',
    location: '',
    website: '',
    description: '',
    startTime:'',
    endTime: '',
    groups: {
      roundRace: [],
      timeRace: [],
      startEndRace: []
    }
  });
  const [loading, setLoading] = useState(true);

  useEffect(() => {
    const fetchEventData = async () => {
      try {
        const eventResponse = axios.get(`/api/events/${id}`);
        const groupsResponse = axios.get(`/api/events/${id}/groupMn`);

        const [eventRes, groupsRes] = await Promise.all([eventResponse, groupsResponse]);

        const formattedGroups = {
          roundRace: [],
          timeRace: [],
          startEndRace: []
        };

        groupsRes.data.forEach(groupMn => {
          const formattedGroup = {
            groupId: groupMn.groupId,
            value: groupMn.value
          };

          switch (groupMn.raceType) {
            case 1:
              formattedGroups.roundRace.push(formattedGroup);
              break;
            case 2:
              formattedGroups.timeRace.push(formattedGroup);
              break;
            case 3:
              formattedGroups.startEndRace.push(formattedGroup);
              break;
            default:
              console.warn(`Unbekannter raceType: ${groupMn.raceType}`);
              break;
          }
        });

        setEventData({
          ...eventRes.data,
          groups: formattedGroups
        });
      } catch (error) {
        console.error('Error fetching event data or groups:', error);
      } finally {
        setLoading(false);
      }
    };

    if (id) {
      fetchEventData();
    }
  }, [id]);

  const handleUpdate = async (formData) => {
    try {
      await axios.put(`/api/events/${id}`, formData);
      router.push('/admin');
    } catch (error) {
      console.error('Error updating event:', error);
    }
  };

  if (loading) {
    return (
      <Container>
        <CircularProgress />
      </Container>
    );
  }

  return (
    <div>
      {eventData ? (
        <EventForm initialValues={eventData} onSubmit={handleUpdate} />
      ) : (
        <Container>
          <CircularProgress />
        </Container>
      )}
    </div>
  );
};

export default EventInformation;
