import { useRouter } from 'next/router';
import { useEffect, useState } from 'react';
import EditableTable from '../../../../components/EditableTable';
import axios from 'axios';
import { CircularProgress, Container, Typography } from '@mui/material';

const ParticipantsPage = () => {
  const router = useRouter();
  const { id } = router.query;
  const [participants, setParticipants] = useState([]);
  const [event, setEvent] = useState(null);
  const [loading, setLoading] = useState(true);

  useEffect(() => {
    const fetchParticipants = async () => {
      try {
        const response = await axios.get(`/api/events/${id}/participants`);
        setParticipants(response.data);
        setLoading(false);
      } catch (error) {
        console.error('Fehler beim Laden der Teilnehmer:', error);
        setLoading(false);
      }
    };

    if (id) {
      fetchParticipants();
    }

    const fetchEventData = async () => {
      try {
        const response = await axios.get(`/api/events/${id}`);
        setEvent(response.data);
        setLoading(false);
      } catch (error) {
        console.error('Error fetching event data:', error);
      }
    };

    if (id) {
      fetchEventData();
    }
  }, [id]);

  if (loading) {
    return (
      <Container>
        <Typography variant="h4" component="h4" gutterBottom>
        Teilnehmer {event ? event.name : `Veranstaltung ${id}`}
        </Typography>
        <CircularProgress />
      </Container>
    );
  }

  return (
    <Container>
      <Typography variant="h4" component="h4" gutterBottom>
      Teilnehmer {event ? event.name : `Veranstaltung ${id}`}
      </Typography>
      <EditableTable eventId={id} initialParticipants={participants} />
    </Container>
  );
};

export default ParticipantsPage;