import { Event, GroupMn } from '../../../../server/db';

export default async function handler(req, res) {
  const { id } = req.query;
  const event = await Event.findByPk(id);

  if (req.method === 'GET') {
    res.status(200).json(event);
  } else if (req.method === 'PUT') {
    const { name, location, website, description, startTime, endTime, groups } = req.body;
    await event.update({ name, location, website, description, startTime, endTime });
    
    if (groups) {
      const existingGroups = await GroupMn.findAll({ where: { eventId: event.eventId } });
      const existingGroupIds = existingGroups.map(g => g.groupId);

      const groupsToAdd = groups.filter(groupId => !existingGroupIds.includes(groupId));
      const groupsToRemove = existingGroupIds.filter(groupId => !groups.includes(groupId));

      if (groupsToRemove.length > 0) {
        await GroupMn.destroy({ 
          where: { 
            eventId: event.eventId, 
            groupId: groupsToRemove 
          } 
        });
      }

      if (groupsToAdd.length > 0) {
        const groupEntries = groupsToAdd.map(({ groupId, raceType, value }) => ({
          eventId: event.eventId,
          groupId,
          raceType,
          value
        }));
        await GroupMn.bulkCreate(groupEntries);
      }
    }
    res.status(201).json(event);

    res.status(200).json(event);
  } else if (req.method === 'DELETE') {
    await event.destroy();
    res.status(204).end();
  }
}
