import { Participant, Group } from '../../../../server/db';

export default async function handler(req, res) {
  if (req.method === 'GET') {
    const { id: eventId } = req.query;
    const participants = await Participant.findAll({ where: { eventId }, include: Group });
    res.status(200).json(participants);
  } else if (req.method === 'POST') {
    const { eventId, first_name, last_name, email, competition } = req.body;
    const newParticipant = await Participant.create({ eventId, first_name, last_name, email, competition });
    res.status(201).json(newParticipant);
  } else if (req.method === 'PUT') {
    const { participantsId, eventId, first_name, last_name, email, competition, startNumber, transponder1 } = req.body;
    const participant = await Participant.findOne({ where: { participantsId } });
    if (participant) {
      participant.eventId = eventId;
      participant.first_name = first_name;
      participant.last_name = last_name;
      participant.email = email;
      participant.competition = competition;
      participant.startNumber = startNumber;
      participant.transponder1 = transponder1;
      await participant.save();
      res.status(200).json(participant);
    } else {
      res.status(404).json({ error: 'Participant not found' });
    }
  } else if (req.method === 'DELETE') {
    const { participantsId } = req.body;
    try {
      await Participant.destroy({ where: { participantsId } });
      res.status(204).end();
    } catch (error) {
      res.status(500).json({ error: 'Failed to delete participant' });
    }
  }
}
