import { sequelize } from '../../../../../server/db';

export default async function handler(req, res) {
  const { eventId, startTime, endTime, raceType, competition, value, startNumber } = req.body;
  var querry;
  switch(raceType){
    case 1:
      querry =
      `SELECT 
        LimitedRounds.time AS round_time,
        LimitedRounds.rn AS round_number
      FROM (
        SELECT 
            t.time,
            ROW_NUMBER() OVER (PARTITION BY p.transponder1 ORDER BY t.time) AS rn
      FROM participants p
      JOIN tracking t ON p.transponder1 = t.transponder
      WHERE p.eventId = :eventId
        AND t.utcTime >= :startTime
        AND t.utcTime <= :endTime
        AND p.competition = :competition
        AND p.startNumber = :startNumber
      ) AS LimitedRounds
      WHERE LimitedRounds.rn <= :value
      ORDER BY round_number ASC;`;
    break;
    case 2:
      querry =
      `SELECT 
        t.time AS round_time
      FROM participants p
      JOIN tracking t ON p.transponder1 = t.transponder
      WHERE p.eventId = :eventId
        AND t.utcTime >= :startTime
        AND p.competition = :competition
        AND p.startNumber = :startNumber
        AND t.time < :value

      UNION ALL

      SELECT 
        MIN(t.time) AS round_time
      FROM participants p
      JOIN tracking t ON p.transponder1 = t.transponder
      WHERE p.eventId = :eventId
        AND t.utcTime >= :startTime
        AND p.competition = :competition
        AND p.startNumber = :startNumber
        AND t.time >= :value
      GROUP BY p.first_name, p.last_name
      ORDER BY round_time;`;
    break;
    case 3:
      querry =
      `SELECT 
        t.time
      FROM tracking t
      JOIN participants p ON p.transponder1 = t.transponder
      WHERE p.eventId = :eventId 
        AND t.utcTime >= :startTime
        AND t.utcTime <= :endTime
        AND p.competition = :competition
        AND p.startNumber = :startNumber;`;
    break;
  };

  const results = await sequelize.query(
    querry,
    {
      replacements: { eventId, startTime, endTime, competition, value, startNumber },
      type: sequelize.QueryTypes.SELECT
    }
  );

  results.forEach((result, index) => {
    result.rank = index + 1;
  });
  res.status(200).json(results);
}