import { sequelize } from '../../../../../server/db';

export default async function handler(req, res) {
  const { eventId, startTime, endTime, raceType, competition, value } = req.body;
  var querry;
  switch(raceType){
    case 1:
      querry =
      `SELECT 
          LimitedRounds.startNumber AS startNumber,
          LimitedRounds.first_name AS first_name,
          LimitedRounds.last_name AS last_name,
          MAX(LimitedRounds.time) AS time,
          COUNT(LimitedRounds.time) AS rounds
      FROM (
          SELECT 
              p.startNumber,
              p.first_name,
              p.last_name,
              t.time,
              ROW_NUMBER() OVER (PARTITION BY p.transponder1 ORDER BY t.time) AS rn
          FROM participants p
          JOIN tracking t ON p.transponder1 = t.transponder
          WHERE p.eventId = :eventId
            AND t.utcTime >= :startTime
            AND t.utcTime <= :endTime
            AND p.competition = :competition
      ) AS LimitedRounds
      WHERE LimitedRounds.rn <= :value
      GROUP BY LimitedRounds.first_name, LimitedRounds.last_name
      ORDER BY time ASC;`;
    break;
    case 2:
      querry =
      `WITH RoundsUnder AS (
        SELECT
          p.startNumber,
          p.first_name,
          p.last_name,
          t.time
        FROM participants p
        JOIN tracking t ON p.transponder1 = t.transponder
        WHERE p.eventId = :eventId 
          AND t.utcTime >= :startTime
          AND p.competition = :competition
          AND t.time < :value
      ),
      FirstRoundOver AS (
        SELECT
          p.startNumber AS startNumber,
          p.first_name AS first_name,
          p.last_name AS last_name,
          MIN(t.time) AS time
        FROM participants p
        JOIN tracking t ON p.transponder1 = t.transponder
        WHERE p.eventId = :eventId
          AND t.utcTime >= :startTime
          AND p.competition = :competition
          AND t.time >= :value
        GROUP BY p.first_name, p.last_name
      )
      SELECT 
        r.startNumber,
        r.first_name,
        r.last_name,
        COALESCE(MAX(f.time), MAX(r.time)) AS time,
        COUNT(r.time) + CASE WHEN f.first_name IS NOT NULL THEN 1 ELSE 0 END AS rounds
      FROM RoundsUnder r
      LEFT JOIN FirstRoundOver f ON r.first_name = f.first_name AND r.last_name = f.last_name
      GROUP BY r.first_name, r.last_name
      ORDER BY rounds DESC, time ASC;`;
    break;
    case 3:
      querry =
      `SELECT 
        p.startNumber AS startNumber,
        p.first_name AS first_name,
        p.last_name AS last_name,
        MIN(t.time) AS time
      FROM participants p
      JOIN tracking t ON p.transponder1 = t.transponder
      WHERE p.eventId = :eventId
        AND t.utcTime >= :startTime
        AND t.utcTime <= :endTime
        AND p.competition = :competition
      GROUP BY t.transponder 
      ORDER BY t.time ASC;`;
    break;
  };

  const results = await sequelize.query(
    querry,
    {
      replacements: { eventId, startTime, endTime, competition, value },
      type: sequelize.QueryTypes.SELECT
    }
  );

  results.forEach((result, index) => {
    result.rank = index + 1;
  });
  res.status(200).json(results);
}