import { spawn } from 'child_process';

let pythonProcess = null;

export default function handler(req, res) {
  const { action } = req.query;

  if (!global.io) {
    return res.status(500).json({ message: 'Socket.io server not initialized' });
  }

  if (action === 'start') {
    if (pythonProcess) {
      return res.status(400).json({ message: 'Process is already running' });
    }
    pythonProcess = spawn('python', ['-u', 'server/reader.py']);

    pythonProcess.stdout.on('data', (data) => {
      global.io.emit('python-output', data.toString());
    });

    pythonProcess.stderr.on('data', (data) => {
      global.io.emit('python-output', data.toString());
    });

    pythonProcess.on('close', (code) => {
      global.io.emit('python-output', `Process exited with code ${code}`);
      pythonProcess = null;
    });

    return res.status(200).json({ message: 'Process started' });

  } else if (action === 'stop') {
    if (pythonProcess) {
      pythonProcess.kill('SIGINT');
      pythonProcess = null;
      return res.status(200).json({ message: 'Process stopped' });
    } else {
      return res.status(400).json({ message: 'No process is running' });
    }
  } else {
    return res.status(400).json({ message: 'Invalid action' });
  }
}