import { Container, Tabs, Tab, IconButton, Box } from '@mui/material';
import { Home } from '@mui/icons-material';
import { useState } from 'react';
import { useRouter } from 'next/router'; 
import EventInformation from './information'; 
import EventRegistration from './registration'; 
import EventParticipants from './participants'; 
import EventResults from './results'; 

function TabPanel(props) {
  const { children, value, index, ...other } = props;
  return (
    <div role="tabpanel" hidden={value !== index} {...other}>
      {value === index && <Box p={3}>{children}</Box>}
    </div>
  );
}

export default function EventDetails() {
  const [tabIndex, setTabIndex] = useState(0);
  const router = useRouter();

  const handleTabChange = (event, newValue) => {
    setTabIndex(newValue);
  };

  const goHome = () => {
    router.push('/');
  };

  return (
    <Container>
      <Box display="flex" alignItems="center">
        <IconButton onClick={goHome} sx={{ mr: 2 }}>
          <Home />
        </IconButton>
        <Tabs value={tabIndex} onChange={handleTabChange}>
          <Tab label="Informationen" />
          <Tab label="Anmeldung" />
          <Tab label="Teilnehmer" />
          <Tab label="Ergebnisse" />
        </Tabs>
      </Box>
      <TabPanel value={tabIndex} index={0}>
        <EventInformation />
      </TabPanel>
      <TabPanel value={tabIndex} index={1}>
        <EventRegistration />
      </TabPanel>
      <TabPanel value={tabIndex} index={2}>
        <EventParticipants />
      </TabPanel>
      <TabPanel value={tabIndex} index={3}>
        <EventResults />
      </TabPanel>
    </Container>
  );
}
