import { useRouter } from 'next/router';
import { Container, Typography, CircularProgress } from '@mui/material';
import axios from 'axios';
import { useEffect, useState } from 'react';

const InformationPage = () => {
  const router = useRouter();
  const { id } = router.query;
  const [event, setEvent] = useState(null);
  const [loading, setLoading] = useState(true);

  useEffect(() => {
    const fetchEventData = async () => {
      try {
        const response = await axios.get(`/api/events/${id}`);
        setEvent(response.data);
        setLoading(false);
      } catch (error) {
        console.error('Error fetching event data:', error);
      }
    };

    if (id) {
      fetchEventData();
    }
  }, [id]);

  if (loading) {
    return (
      <Container>
        <CircularProgress />
      </Container>
    );
  }

  return (
    <Container>
      <Typography variant="h4" component="h4" gutterBottom>
        {event ? event.name : `Veranstaltung ${id}`}
      </Typography>
      {event ? (
        <div>
          <Typography variant="body1" gutterBottom>Ort: {event.location}</Typography>
          <Typography variant="body1" gutterBottom>Website: {event.website}</Typography>
          <Typography variant="body1" gutterBottom>Beschreibung: {event.description}</Typography>
        </div>
      ) : (
        <Typography variant="body1">Es wurden keine Informationen gefunden.</Typography>
      )}
    </Container>
  );
};

export default InformationPage;
