import { useState, useEffect } from 'react';
import { useRouter } from 'next/router';
import { Container, Typography, TextField, Button, Grid, MenuItem, Select, InputLabel, FormControl } from '@mui/material';
import axios from 'axios';

const RegistrationPage = () => {
  const router = useRouter();
  const { id } = router.query;
  const [event, setEvent] = useState(null);
  const [groupMn, setGroupMn] = useState([]);
  const [formData, setFormData] = useState({
    eventId: id,
    first_name: '',
    last_name: '',
    email: '',
    competition: ''
  });

  useEffect(() => {
    const fetchEventData = async () => {
      try {
        const response = await axios.get(`/api/events/${id}`);
        setEvent(response.data);
      } catch (error) {
        console.error('Error fetching event data:', error);
      }
    };

    const fetchGroupMn = async () => {
      try {
        const response = await axios.get(`/api/events/${id}/groupMn`);
        setGroupMn(response.data);
      } catch (error) {
        console.error('Error fetching groupMn:', error);
      }
    };

    if (id) {
      fetchEventData();
      fetchGroupMn();
    }
  }, [id]);

  const handleChange = (e) => {
    const { name, value } = e.target;
    setFormData({
      ...formData,
      [name]: value
    });
  };

  const handleSubmit = async (e) => {
    e.preventDefault();
    try {
      await axios.post(`/api/events/${id}/participants`, formData);
      router.push(`/events/${id}/participants`);
    } catch (error) {
      console.error('Error registering for event:', error);
    }
  };

  return (
    <Container>
      <Typography variant="h4" component="h4" gutterBottom>
        Anmeldung {event ? event.name : ''}
      </Typography>
      <form onSubmit={handleSubmit}>
        <Grid container spacing={2}>
          <Grid item xs={12}>
            <TextField
              name="first_name"
              label="Vorname"
              variant="outlined"
              fullWidth
              value={formData.first_name}
              onChange={handleChange}
              required
            />
          </Grid>
          <Grid item xs={12}>
            <TextField
              name="last_name"
              label="Nachname"
              variant="outlined"
              fullWidth
              value={formData.last_name}
              onChange={handleChange}
              required
            />
          </Grid>
          <Grid item xs={12}>
            <TextField
              name="email"
              label="E-Mail"
              variant="outlined"
              fullWidth
              type="email"
              value={formData.email}
              onChange={handleChange}
              required
            />
          </Grid>
          <Grid item xs={12}>
            <FormControl fullWidth>
              <InputLabel id="competition-label">Gruppe</InputLabel>
              <Select
                labelId="competition-label"
                name="competition"
                value={formData.competition}
                onChange={handleChange}
                required
              >
                {groupMn.map((item) => (
                  <MenuItem key={item.Group.groupId} value={item.Group.groupId}>
                    {item.Group.name}
                  </MenuItem>
                ))}
              </Select>
            </FormControl>
          </Grid>
          <Grid item xs={12}>
            <Button type="submit" variant="contained" color="primary">
              Anmelden
            </Button>
          </Grid>
        </Grid>
      </form>
    </Container>
  );
};

export default RegistrationPage;
