const { Sequelize, DataTypes } = require('sequelize');
require('dotenv').config();

const sequelize = new Sequelize(process.env.DATABASE_URL, {
  dialect: 'mysql',
});

const Event = sequelize.define('Event', {
  eventId: {
    type: DataTypes.INTEGER,
    primaryKey: true,
    autoIncrement: true,
  },
  name: {
    type: DataTypes.STRING,
    allowNull: false,
  },
  location: {
    type: DataTypes.STRING,
  },
  website: {
    type: DataTypes.STRING,
  },
  description: {
    type: DataTypes.TEXT,
  },
  startTime: {
    type: DataTypes.DATE,
  },
  endTime: {
    type: DataTypes.DATE,
  },
}, {
  tableName: 'events',
  timestamps: false,
});

const Participant = sequelize.define('Participant', {
  participantsId: {
    type: DataTypes.INTEGER,
    primaryKey: true,
    autoIncrement: true,
  },
  eventId: {
    type: DataTypes.INTEGER,
  },
  startNumber: {
    type: DataTypes.INTEGER,
  },
  last_name: {
    type: DataTypes.STRING(100),
  },
  first_name: {
    type: DataTypes.STRING(100),
  },
  title: {
    type: DataTypes.STRING(15),
  },
  birth_year: {
    type: DataTypes.INTEGER,
  },
  birth_date: {
    type: DataTypes.DATE,
  },
  gender: {
    type: DataTypes.STRING(2),
  },
  nationality: {
    type: DataTypes.STRING(50),
  },
  competition: {
    type: DataTypes.INTEGER,
  },
  club: {
    type: DataTypes.STRING(100),
  },
  license: {
    type: DataTypes.STRING(25),
  },
  status: {
    type: DataTypes.INTEGER,
  },
  comment: {
    type: DataTypes.TEXT,
  },
  transponder1: {
    type: DataTypes.STRING(40),
  },
  transponder2: {
    type: DataTypes.STRING(40),
  },
  reg_number: {
    type: DataTypes.INTEGER,
  },
  street: {
    type: DataTypes.STRING(100),
  },
  postal_code: {
    type: DataTypes.STRING(10),
  },
  city: {
    type: DataTypes.STRING(50),
  },
  state: {
    type: DataTypes.STRING(3),
  },
  country: {
    type: DataTypes.STRING(50),
  },
  email: {
    type: DataTypes.STRING(100),
  },
  phone: {
    type: DataTypes.STRING(50),
  },
  mobile: {
    type: DataTypes.STRING(255),
  },
  account_holder: {
    type: DataTypes.STRING(50),
  },
  account_number: {
    type: DataTypes.STRING(12),
  },
  bank_code: {
    type: DataTypes.STRING(12),
  },
  bank_name: {
    type: DataTypes.STRING(50),
  },
  iban: {
    type: DataTypes.STRING(36),
  },
  bic: {
    type: DataTypes.STRING(11),
  },
  sepa_mandate: {
    type: DataTypes.STRING(35),
  },
}, {
  tableName: 'participants',
  timestamps: false,
});

const Tracking = sequelize.define('Tracking', {
  trackingId: {
    type: DataTypes.INTEGER,
    primaryKey: true,
    autoIncrement: true,
  },
  transponder: {
    type: DataTypes.STRING(40),
  },
  time: {
    type: DataTypes.FLOAT,
  },
  hits: {
    type: DataTypes.INTEGER,
  },
  timingPoint: {
    type: DataTypes.STRING(100),
  },
  decoderId: {
    type: DataTypes.STRING(50),
  },
  utcTime: {
    type: DataTypes.DATE,
  },
}, {
  tableName: 'tracking',
  timestamps: false,
});

const Group = sequelize.define('Group', {
  groupId: {
    type: DataTypes.INTEGER,
    primaryKey: true,
    autoIncrement: true,
  },
  name: {
    type: DataTypes.STRING(255),
  },
}, {
  tableName: 'groups',
  timestamps: false,
});

const GroupMn = sequelize.define('GroupMn', {
  id: {
    type: DataTypes.INTEGER,
    primaryKey: true,
    autoIncrement: true,
  },
  eventId: {
    type: DataTypes.INTEGER,
  },
  groupId: {
    type: DataTypes.INTEGER,
  },
  raceType: {
    type: DataTypes.INTEGER,
  },
  value: {
    type: DataTypes.INTEGER,
    defaultValue: 0
  },
}, {
  tableName: 'groupsMn',
  timestamps: false,
});

Event.hasMany(Participant, { foreignKey: 'eventId' });
Participant.belongsTo(Event, { foreignKey: 'eventId' });

Event.hasMany(Tracking, { foreignKey: 'eventId' });
Tracking.belongsTo(Event, { foreignKey: 'eventId' });

Event.hasMany(GroupMn, { foreignKey: 'eventId' });
GroupMn.belongsTo(Event, { foreignKey: 'eventId' });

Group.hasMany(GroupMn, { foreignKey: 'groupId' });
GroupMn.belongsTo(Group, { foreignKey: 'groupId' });

Participant.hasMany(Tracking, { foreignKey: 'participantId' });
Tracking.belongsTo(Participant, { foreignKey: 'participantId' });

Group.hasMany(Participant, { foreignKey: 'competition' });
Participant.belongsTo(Group, { foreignKey: 'competition' });

module.exports = { sequelize, Event, Participant, Tracking, Group, GroupMn };